@@ -126,8 +126,8 @@ class In(ListFinalCondition):
     operator = 'IN'
 
 
-class NotIn(ListFinalCondition):
-    operator = 'NOTIN'
+def NotIn(rtype, value):
+    return Not(In(rtype, value))
 
 
 class Not(Condition):
